/**
 * A joogl ambient light object.  
 * <p>
 * This object creates an ambient light when attached to the scene graph.    
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public class jooglAmbientLight extends jooglLight {
    
    /**
     * Constructor function for an AmbientLight, using floats.
     * <p>
     * Specify the RGB values for the light color.  A default intensity of 1.0 is used.
     * 
     * @param r		the red component of the light, from 0 to 1
     * @param g		the green component of the light, from 0 to 1
     * @param b		the blue component of the light, from 0 to 1
     */
    public jooglAmbientLight(float _r, float _g, float _b)
    {
        super(_r, _g, _b);
    }    
    
    /**
     * Constructor function for an AmbientLight, using doubles.
     * <p>
     * Specify the RGB values for the light color.  A default intensity of 1.0 is used.
     * 
     * @param r		the red component of the light, from 0 to 1
     * @param g		the green component of the light, from 0 to 1
     * @param b		the blue component of the light, from 0 to 1
     */
    public jooglAmbientLight(double _r, double _g, double _b)
    {
        super((float)_r, (float)_g, (float)_b);
    }    

    /**
     * Create a new jooglAmbientLight with the same properties
     * as this object.
     */
    public jooglNode snapshot(long time) {
    	jooglAmbientLight ret = new jooglAmbientLight(r, g, b);

	if(material != null)
	        ret.setMaterial(material.snapshot(time));
	       
	if(transform != null)
	    	ret.setTransform(transform.snapshot(time));

	if(drawMode != null)
	    	ret.setDrawMode(drawMode.snapshot(time));
	    	
	if(shadeMode != null)
	    	ret.setShadeMode(shadeMode.snapshot(time));

	if(pickable != null)
	    	ret.setPickable(pickable.snapshot(time));

 	return ret;
    }
    
    /**
    * Activate the light.
    * <p>
    * This is an internal function, called during rendering to turn on this light using a specified OpenGL 
    * light number.   If the light is on, the OpenGL light will be set to be the appropriate ambient light.
    *
    * @param lightNum    set OpenGL light "lightNum" to this ambient light
    * @return   Indicates if the light is turned on or off.
    */
    protected boolean activate(int lightNum)
    {
        if (lightOn) {
            gl.glLightfv(lightNum, GL_AMBIENT, lm);
	    gl.glLightfv(lightNum, GL_DIFFUSE, zeroLight);
	    gl.glLightfv(lightNum, GL_SPECULAR, zeroLight);
            gl.glEnable(lightNum);
            return true;
        }
        return false;
    }
}
