/**
 * The geometry node for a cube.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglCube extends jooglGeometry implements Cloneable {
    /** The size of the cube. */
    protected double size;
    
    /** Create a cube of a specified size 
     * @param _size the size of the cube
     */
    public jooglCube (double _size)
    {
        super();
        size = _size;
    }
    
    /** Create a cube of the default size, 1.0 units. 
     */
    public jooglCube ()
    {
        super();
        size = 1.0;
    }

    /**
     * Create a new jooglCube object with fields
     * identical to this object's.
     */
    public jooglNode snapshot(long time) {
    	jooglCube ret;
    	try{
    		ret = (jooglCube)clone();
    	} catch(CloneNotSupportedException e) { return null; }

	if(material != null)
	        ret.setMaterial(material.snapshot(time));
	       
	if(transform != null)
	    	ret.setTransform(transform.snapshot(time));

	if(drawMode != null)
	    	ret.setDrawMode(drawMode.snapshot(time));
	    	
	if(shadeMode != null)
	    	ret.setShadeMode(shadeMode.snapshot(time));

	if(pickable != null)
	    	ret.setPickable(pickable.snapshot(time));

	return ret;
    }

    /**
     * Set the size of the cube.
     * 
     * @param _size the new size of the cube.
     */
    public void setSize(double _size)
    {
        size = _size;
        redrawWindows();
    }

    /**
     * Get the size of the cube.
     * 
     * @return the current size of the cube.
     */
    public double getSize()
    {
        return size;
    }
    
    /** Internal function, to recreate the cube display list */
    protected void recreateDisplayList()
    {	
	gl.glNewList(dl, GL_COMPILE);
	glut.glutSolidCube(size);
	gl.glEndList();
    }
}
