/**
 * The drawing mode property node.
 * <p>
 * The drawing mode is either FILL, LINE or POINT.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglDrawMode extends jooglProperty {
    /** Draw the object filled. */
    public static final int FILL = GL_FILL;
    /** Draw the object as a collection of lines. */
    public static final int LINE = GL_LINE;
    /** Draw the object as a collection of points. */
    public static final int POINT = GL_POINT;

    /** The current mode for this property. */
    protected int mode;

    /**
     * Create a jooglDrawMode property with the default mode, FILL. 
     */
    public jooglDrawMode()
    {
        super(PROP_DRAWMODE);
	mode = FILL;
    }
        
    /**
     * Create a jooglDrawMode property with the specified mode. 
     *
     * @param _mode the mode to use. 
     */
    public jooglDrawMode(int _mode)
    {
        super(PROP_DRAWMODE);
	mode = _mode;
    }

    /**
     * Create a new instance of jooglDrawMode with fields
     * the same as this object.
     */
    public jooglDrawMode snapshot(long time) {
    	return new jooglDrawMode(mode);
    }
    
    /**
     * Set the mode of the property. 
     *
     * @param _mode the mode to use. 
     */
    public void setMode(int _mode)
    {
	mode = _mode;
        //redrawWindows();
    }

    /**
     * Get the mode of the property. 
     *
     * @return the current mode
     */
    public int getMode()
    {
        return mode;
    }
        
    /** 
     * Get the value of the property at time t.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return the draw mode
     */
    public int getValue(long time)
    {
        // this is a constant property.  Override this method to create a time varying property.
        return mode;
    }

    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        // constant, so do nothing
    }
    
    /** Internal Method, to set the OpenGL state for this property.  Called when the stacks are pushed and popped.
     *
     * Only put things here that can be called multiple times safely. 
     */
    protected void apply()
    {
        gl.glPolygonMode (GL_FRONT, mode);
    }

}
