/**
 * The dynamic drawing mode property node.
 * <p>
 * The object is dynamic.  It must be subclassed, and have its abstract "getValue" method overridden.
 * This method should compute the value of the property at the requested time.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public abstract class jooglDynamicDrawMode extends jooglDrawMode {
    /** what is the time at which I was last cached? */
    protected long cacheTime = -1;

    /** Create a dynamic drawmode property */
    public jooglDynamicDrawMode()
    {
        super();
    }
    
    /**
     * Creates a jooglDrawMode object that represents the value
     * of this object at the given time.
     */
    public jooglDrawMode snapshot(long time) {
    	return new jooglDrawMode(getValue(time));
    }
    
    /** 
     * Is this property object dynamic or static?
     * <p>
     * Override this method because this is a dynamic subclasses. 
     *
     * @return true because the property is dynamic.
     */
    protected boolean isDynamic()
    {	
        return true;
    }
    
    /** 
     * Get the value of the property at time t.
     * <p>
     * This method must be overridden with a method that computes the dynamic property value.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return the draw mode
     */
    public abstract int getValue(long time);

    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     * The cache should not be recomputed if the time is the same as the previous call.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        if (time != cacheTime)
        {
            cacheTime = time;
            mode = getValue(time);
        }
    }
}
