/**
 * The drawing mode property node.
 * <p>
 * The "pickable" property infomation.   Pickable properties can be enabled and disabled
 * so that objects can be made unpickable without having to remove the property.
 * <p>
 * The object is dynamic.  It must be subclassed, and have its abstract "getValue" method overridden.
 * This method should compute the value of the property at the requested time.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public abstract class jooglDynamicPickable extends jooglPickable {
    /** what is the time at which I was last cached? */
    protected long cacheTime = -1;
            
    /** 
     * Is this property object dynamic or static?
     * <p>
     * Override this method because this is a dynamic subclasses. 
     *
     * @return true because the property is dynamic.
     */
    protected boolean isDynamic()
    {	
        return true;
    }
    
    /**
     * Create a jooglPickable object that represents
     * the state of this object at the given time.
     */
    public jooglPickable snapshot(long time) {
    	jooglPickable ret = new jooglPickable();
    	ret.setPickable(getValue(time));
    	return ret;
    }
    
    /** 
     * Get the value of the property at time t.
     * <p>
     * This method must be overridden with a method that computes the dynamic property value.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return true if the property is enabled
     */
    public abstract boolean getValue(long time);
        
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     * The cache should not be recomputed if the time is the same as the previous call.
     * 
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        if (time != cacheTime)
        {
            cacheTime = time;
            pickable = getValue(time);
        }
    }
}
