/**
 * The dynamic transform property node.
 * <p>
 * The object is dynamic.  It must be subclassed, and have its abstract "getValue" method overridden.
 * This method should compute the value of the property at the requested time.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public abstract class jooglDynamicTransform extends jooglTransform {
    /** what is the time at which I was last cached? */
    protected long cacheTime = -1;

    /**
     * Create a jooglTransform object that represents the
     * state of this object at the given time.
     */
    public jooglTransform snapshot(long time) {
    	return new jooglTransform(getValue(time));
    }

    /** 
     * Get the value of the property at time t.
     * <p>
     * This method must be overridden with a method that computes the dynamic property value.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return a 16 element array holding the current transform
     */
    public abstract double[] getValue(long time);
        
    /** 
     * Is this property object dynamic or static?
     * <p>
     * Override this method because this is a dynamic subclasses. 
     *
     * @return true because the property is dynamic.
     */
    protected boolean isDynamic()
    {	
        return true;
    }
    
    /**
     * Internal Method, to cache the value of the property at time t in the property state variable.
     * The cache should not be recomputed if the time is the same as the previous call.
     * <p>
     * @param time the time in milliseconds at which the property should be evaluated
     */
    protected void cacheValue(long time)
    {
        if (time != cacheTime)
        {
            cacheTime = time;
            double[] m = getValue(time);
            
            for (int i=0; i<16; i++)
                matrix[i] = m[i];
        }
    }
}
