/**
 * The base class for all geometry nodes.   All common methods and fields go here.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */

public abstract class jooglGeometry extends jooglNode implements Cloneable {
    /** the OpenGL display list for the geometry */
    protected int dl = -1;
    
    /** A flag that says if the geometry need to be recreated before rendering. */
    protected boolean dirty = true;
    
    /** Create a geometry node */
    public jooglGeometry()
    {
        super();
    }
    
    /**
     * Abstract method to create the OpenGL display list.
     * <p>
     * All geometry nodes MUST implement this method to create their geometry.
     */
    protected abstract void recreateDisplayList();
    
    /**
     * Rebuild the geometry if the node is dirty.
     *
     * @return true if the object was rebuilt.
     */
    protected boolean repair()
    {
        if (!dirty)
            return false;
        if (dl == -1)
            dl = gl.glGenLists(1);
        //System.out.println("repair dl " + dl);    
        dirty = false;
        recreateDisplayList();
        return true;
    }
    
    /** Render the geometry */
    protected void render()
    {
        //System.out.println("call list: " + dl);
        gl.glCallList(dl);
    }
}
