import java.io.*;

/**
 * The dynamic transform class that is used for mocap animation.
 * <p>
 * This is a subclass of jooglDynamicTransform.  It stores an array of coordinates that represent the different frames.
 * The getValue method returns the transform for the appropriate frame.
 *
 * @version 	1.00
 * @author      Ben Carter
 */
public class jooglMocapDynamicTransform extends jooglDynamicTransform {
    private double frames[][];
    private double millisPerFrame;
    private int numFrames;
    
    public jooglMocapDynamicTransform(double[][] positions, long framesPerSecond, int frameCount) {
    	millisPerFrame = 1000.0 / framesPerSecond;
    	numFrames = frameCount;
    	frames = positions;
//    	System.out.println("Number of frames: " + frameCount);
    }
    
    /** 
     * Get the translation matrix for the passed time.
     *
     * @param time the time in milliseconds at which the property should be evaluated
     * @return a 16 element array holding the current transform
     */
    public double[] getValue(long time) {
	int currFrame = (int)(time / millisPerFrame) % numFrames;
    	setIdentity();
    	translate(frames[currFrame][0], frames[currFrame][1], frames[currFrame][2]);
    	return matrix;
    }
    
    /**
     * Set the position for each frame
     */
    public void setFrames(double[][] positions) {
    	frames = positions;
    }
    
    /**
     * Set the frame rate in frames per second
     */
    public void setFrameRate(long framesPerSecond) {
    	millisPerFrame = 1000.0 / framesPerSecond;
    }
}
